/// <reference types="node" />
export declare enum CmdShow {
    SW_HIDE = 0,
    SW_SHOWNORMAL = 1,
    SW_SHOWMINIMIZED = 2,
    SW_SHOWMAXIMIZED = 3,
    SW_MAXIMIZE = 3,
    SW_SHOWNOACTIVATE = 4,
    SW_SHOW = 5,
    SW_MINIMIZE = 6,
    SW_SHOWMINNOACTIVE = 7,
    SW_SHOWNA = 8,
    SW_RESTORE = 9,
    SW_SHOWDEFAULT = 10,
    SW_FORCEMINIMIZE = 11,
}
export declare type matchParam = number | string;
export interface Api {
    EnumWindows: EnumWindows;
    GetWindowThreadProcessId(hWnd: number, lpdwProcessId: Buffer): number;
    GetWindowTextW(hWnd: number, lpString: Buffer, nMaxCount: number): number;
    IsWindowVisible(hWnd: number): boolean;
    ShowWindow(hWnd: number, nCmdShow: number): boolean;
    GetParent(hWnd: number): number | null;
    GetAncestor(hwnd: number, gaFlags: number): number;
}
export interface EnumWindows {
    (lpEnumFunc: Buffer, lParam: Tno): boolean;
    async(lpEnumFunc: Buffer, lParam: Tno, cb: (err: Error) => void): boolean;
}
export declare type Tno = number;
export declare type Pid = number;
export declare type Hwnd = number;
export declare type ErrCode = number;
export interface ExecRet {
    err: ErrCode;
    msg: string;
    pids: Pid[];
    hwnds: Hwnd[];
}
export default function showWindow(hWnd: number, nCmdShow: CmdShow): ErrCode;
export declare function validate_cmdshow(nCmdShow: CmdShow): boolean;
export declare function hide(p: matchParam, onlyMainWin?: boolean): Promise<ExecRet>;
export declare function show(p: matchParam, nCmdShow: CmdShow, onlyMainWin?: boolean): Promise<ExecRet>;
export declare function get_main_hwnd(p: matchParam): Promise<number | void>;
export declare function get_hwnds(p: matchParam): Promise<number[] | void>;
export declare function kill(p: matchParam): Promise<ExecRet>;
